To install fastrometry, use:

    pip install fastrometry

Note that you must have a Python version of 3.10 or higher.

To use fastrometry, simply call fastrometry at the command line:

    fastrometry -option1 -option2 ...

For more info, please visit the wiki: https://github.com/user29A/fastrometry/wiki

This project was undertaken with the financial support of the Canadian Space Agency.